@@ -1,4 +1,4 @@
 library(testthat)
 library(loon.tourr)
 
-# testthat::test_check("loon.tourr")
+testthat::test_check("loon.tourr")
